summaryrefslogtreecommitdiffstats
path: root/kdevdesigner/shared/domtool.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdevdesigner/shared/domtool.cpp')
-rw-r--r--kdevdesigner/shared/domtool.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/kdevdesigner/shared/domtool.cpp b/kdevdesigner/shared/domtool.cpp
index ef995e44..4293224f 100644
--- a/kdevdesigner/shared/domtool.cpp
+++ b/kdevdesigner/shared/domtool.cpp
@@ -1,15 +1,15 @@
/**********************************************************************
** Copyright (C) 2000 Trolltech AS. All rights reserved.
**
** This file is part of Qt Designer.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
-** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
+** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
+** licenses may use this file in accordance with the TQt Commercial License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
@@ -17,7 +17,7 @@
**
** See http://www.trolltech.com/gpl/ for GPL licensing information.
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-** information about Qt Commercial License Agreements.
+** information about TQt Commercial License Agreements.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
@@ -352,7 +352,7 @@ static bool toBool( const TQString& s )
}
/*!
- Convert Qt 2.x format to Qt 3.0 format if necessary
+ Convert TQt 2.x format to TQt 3.0 format if necessary
*/
void DomTool::fixDocument( TQDomDocument& doc )
{
@@ -404,9 +404,9 @@ void DomTool::fixDocument( TQDomDocument& doc )
bool stdset = toBool( e.attribute( "stdset" ) );
if ( stdset || name == "toolTip" || name == "whatsThis" ||
name == "buddy" ||
- e.parentNode().toElement().tagName() == "item" ||
- e.parentNode().toElement().tagName() == "spacer" ||
- e.parentNode().toElement().tagName() == "column"
+ e.tqparentNode().toElement().tagName() == "item" ||
+ e.tqparentNode().toElement().tagName() == "spacer" ||
+ e.tqparentNode().toElement().tagName() == "column"
)
e.removeAttribute( "stdset" );
else
@@ -1,15 +1,15 @@
** Copyright (C) 2000 Trolltech AS. All rights reserved.
**
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
**
** This file may be distributed and/or modified under the terms of the